@@ -1,3 +1,4 @@
+from datetime import datetime
 from enum import Enum
 
 
@@ -96,3 +97,23 @@ class FilterParams(Enum):
     time_current = "NOW"
     capitalize = "CAPITALIZE"
     capitalize_all = "CAPITALIZEALL"
+
+formules = [
+    "FIXED",
+    "UPPERCASE",
+    "LOWERCASE",
+    "NOW",
+    "CAPITALIZE",
+    "CAPITALIZEALL",
+    "WITHOUTSPACE"
+]
+
+actions = {
+    "FIXED": lambda data, fixed_number: round(data, fixed_number),
+    "UPPERCASE": lambda data: data.upper(),
+    "LOWERCASE": lambda data: data.lower(),
+    "NOW": datetime.today(),
+    "CAPITALIZE": lambda data: data.capitalize(),
+    "CAPITALIZEALL": lambda data: data.title(),
+    "WITHOUTSPACE": lambda data: data.replace(' ', '')
+}
